**********************************************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************
************* How Often Do Dictators Have Positive Economic Effects? Global Evidence, 1858-2010 **********************
************* Replication code: Tables 1 - 11, Figures, Appendix Tables **********************************************
************* Stephanie Rizio and Ahmed Skali ************************************************************************ 
************* June 2019 **********************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************
**********************************************************************************************************************


* Load dataset

use "Data_LQ_final.dta", clear

* Log results - uncomment to enable:
*log using "LQReplicationLog.smcl", replace

* The code below replicates Tables 1 - 11 of the paper, and appendix tables

* First, generate interactions of leader dummies and main measure of autocracy (=1 if Polity2<6)


tab leaderid, gen(lfe)

forvalues j = 1(1)1268 {

g leader`j'autocracy6 = lfe`j' * autocracy6

}


* Analogous code to the above is given for other cutoffs below where appropriate





************************************************************************************
************************* FIGURE 1 *************************************************

* This figure uses GDP data from the World Development Indicators, as Maddison coverage
* for Congo DR is patchy.

preserve

* load Congo DR dataset

 use "/Users/ahmedskali/Google Drive/Papers/benevolent/LQ_MethodsReview/Fig1.dta", clear
*use "Fig1.dta", clear

* Left-hand side:
twoway scatter lngdpwdi year , ///
xline(1965) xline(1997)  ylabel(, nogrid) xlabel(, nogrid) ///
ytitle("ln(GDP per capita), 2005 USD (WDI)") ///
text(5.1 1965.5  "Mobutu takes office", placement(e) size(vsmall)) ///
text(5.1 1997.5  "Mobutu leaves office", placement(e) size(vsmall)) plotregion(color(white)) 

* Right-hand side:
twoway scatter growth_pos year , ///
xline(1965) xline(1997)  ylabel(, nogrid) xlabel(, nogrid)  ytitle("Growth Rate") ///
|| scatter growth_neg year if countryname=="Congo. Dem. Rep." & year>1960, ///
text(0.1 1965.5  "Mobutu takes office", placement(e) size(vsmall)) ///
text(0.1 1997.5  "Mobutu leaves office", placement(e) size(vsmall)) plotregion(color(white))

restore


************************************************************************************
************************* FIGURE 2 *************************************************

twoway scatter polity2 year if countryname=="Spain" & year>1869 ///
,  ylabel(, nogrid) xlabel(, nogrid) ///
ytitle("Revised Combined Polity2 Score") ///
plotregion(color(white)) ///
xline(1975) xline(1936) xline(1923) xline(1931) ///
text(-9 1931.1  "Second Republic", placement(e) size(vsmall)) ///
text(-8 1923.1  "Primo de Rivera coup", placement(e) size(vsmall)) ///
text(-10 1936.1  "Civil war / Franco takes office", placement(e) size(vsmall)) ///
text(-10 1975.1  "Franco dies", placement(e) size(vsmall))


************************************************************************************
************************* TABLE 1 **************************************************

preserve

  bys leaderid: egen meangrowth = mean(growth)
  bys leaderid: egen meanpolity = mean(polity2)
  
  cap drop test
  
  bys leaderid: g test = _n
  
  keep if test==1
  
  g leader_dem = 0
  replace leader_dem = 1 if meanpolity>5
  
  ttest meangrowth, by(leader_dem)
  
  ttest meanpolity, by(leader_dem)
  
  ttest tenurelength, by(leader_dem)
  
restore

************************************************************************************
************************* TABLE 2 **************************************************

preserve

  bys leaderid: egen meangrowth = mean(growth)
  bys leaderid: egen meanpolity = mean(polity2)

  cap drop test
  
  bys leaderid: g test = _n
  
  keep if test==1
  
  sort meangrowth
	
	xtile quintile = meangrowth, nquantiles(5)
	
     tab quintile leader_dem, chi2
	 
	 ksmirnov quintile, by(leader_dem)

restore

************************************************************************************
************************* TABLE 3 **************************************************



preserve

 * define min and max polity2 score per tenure
 bys spellid: egen minpolity=min(polity2)
 bys spellid: egen maxpolity=max(polity2)
 
 * define min and max year per tenure
 bys spellid: egen minyear = min(year)
 bys spellid: egen maxyear = max(year)
 
 * keep min and max year
 keep if year==minyear | year==maxyear
 
 sort cid year

 xtset cid year

 * calculate change in polity2 score between start and end of tenure
 g inst_change = polity2 - l.polity2

 * How many cases of no change?
 tab inst_change
 * == 0 in 1201 cases
 
 * With respect to a threshold of Polity2 == 6:
 
 * How many cases of remaining autocratic?
 sum inst_change if (minpolity<6 & maxpolity<6) & inst_change!=0

 * How many cases of remaining democratic?
 sum inst_change if  (minpolity>=6 & maxpolity>=6) & inst_change!=0
 
 * How many cases of becoming democratic?
 sum inst_change if (minpolity<6 & maxpolity>=6) & inst_change>0

 * How many cases of becoming autpcratic?
 sum inst_change if (minpolity<6 & maxpolity>=6) & inst_change<0

restore



************************************************************************************
************************* TABLE 4 **************************************************

* C1
*reg growth leader*autocracy6


* C2
xtreg growth leader*autocracy6 if tenurelength>2

* C3
xtreg growth leader*autocracy6 if tenurelength>5

* C4
xtreg growth leader*autocracy6 if tenurelength>10

* C5
xtreg growth leader*_autocracy6 i.year



************************************************************************************
************************* TABLE 5 **************************************************

*** Step (1) run ONE of the following regressions:
* Row 1
xtreg transition l.growth l.autocracy6 l.growth_autocracy i.year, fe
* Row 2
xtreg transition l.growth l.autocracy6 l.growth_autocracy l2.growth l2.autocracy6 l2.growth_autocracy i.year, fe
* Row 3
xtreg transition l.growth l.autocracy6 l.growth_autocracy l2.growth l2.autocracy6 l2.growth_autocracy l3.growth l3.autocracy6 l3.growth_autocracy i.year, fe
* Row 4
xtreg transition l.growth l.autocracy6 l.growth_autocracy l2.growth l2.autocracy6 l2.growth_autocracy l3.growth l3.autocracy6 l3.growth_autocracy l4.growth l4.autocracy6 l4.growth_autocracy i.year, fe
* Row 5
xtreg transition l.growth l.autocracy6 l.growth_autocracy l2.growth l2.autocracy6 l2.growth_autocracy l3.growth l3.autocracy6 l3.growth_autocracy l4.growth l4.autocracy6 l4.growth_autocracy  l5.growth l5.autocracy6 l5.growth_autocracy i.year, fe

*** Step (2) Obtain predicted probability of transition
cap drop fitted
predict fitted

*** Step (3) t-test whether predicted probability of transition differs by regime type
ttest fitted, by(autocracy6)



************************************************************************************
************************* TABLE 6 **************************************************

* C1
* Get predicted probability of transition
xtreg transition i.year  l.growth l.autocracy6 l.growth_autocracy, fe
cap drop fitted
predict fitted
* Use as control
xtreg growth leader*autocracy6 fitted i.year

* C2
* install xtivreg2 if not install
cap ssc install xtivreg2
* Get first stage F-test
xtivreg2 transition (l.growth = l2.g_f) i.year, fe first
* Get first stage predicted values
xtreg l.growth i.year  l2.g_f , fe
predict fitted_g
* Make interaction g * Autocracy
g fitted_g_autocr = fitted_g * autocracy6
* Get second stage predicted values
xtreg transition yfe*  l.fitted_g l.autocracy6 l.fitted_g_autocr, fe
predict fitted_2
* Use second stage predicted values as control
xtreg growth leader*autocracy6 fitted_2 i.year
 
* C3
* make relevant dummies
forvalues j = 1(1)1268 {
g leader`j'_everautocrat = lfe`j' * ever_autocrat
}
xtreg growth leader*_everautocrat i.year

* C4
* make relevant dummies
forvalues j = 1(1)1268 {
g leader`j'_fullautocr = lfe`j' * fullautocr
}
xtreg growth leader*_fullautocr i.year

* C5
* make relevant dummies
forvalues j = 1(1)1268 {
g leader`j'_closedanoc = lfe`j' * closedanoc
}
xtreg growth leader*_closedanoc i.year

* C6
* make relevant dummies
forvalues j = 1(1)1268 {
g leader`j'_openanoc = lfe`j' * openanoc
}
xtreg growth leader*_openanoc i.year

************************************************************************************
************************* TABLE 7 **************************************************

* C1
* generate 9th lag of each (leader * autocracy) variable
forvalues j = 1(1)1825 {
g leader`j'_autocracy_l9 = l9.lfe`j' * l9.autocracy6
}
xtreg growth leader*_autocracy_l9 i.year

* C2
* mark year 1 of tenure and exclude from appropriate leader dummy by setting equal to 0
sort leadid2 year
by leadid2: g yr_order = _n
forvalues j = 1(1)1825 {
replace leader`j'autocracy6 = 0 if yr_order ==1
}
xtreg growth leader*autocracy6 i.year

* C3
* same as C2, for years 1 and 2 of tenure
forvalues j = 1(1)1825 {
replace leader`j'autocracy6 = 0 if yr_order ==1 | yr_order==2
}
xtreg growth leader*autocracy6 i.year

* C4
sort leadid2 year
by leadid2: g yr_order = _n
bys leadid2: egen maxyr = max(yr_order)
g lastyear = 0
replace lastyear = 1 if yr_order==maxyr
forvalues j = 1(1)1825 {
replace leader`j'autocracy6 = 0 if lastyear==1
}
xtreg growth leader*autocracy6 i.year

* C5
sort leadid2 year
by leadid2: g yr_order = _n
bys leadid2: egen maxyr = max(yr_order)
g lastyear = 0
replace lastyear = 1 if yr_order==maxyr
g secondlastyear = 0
replace secondlastyear = 1 if yr_order == maxyr - 1
forvalues j = 1(1)1825 {
replace leader`j'autocracy6 = 0 if lastyear==1 | secondlastyear==1
}
xtreg growth leader*autocracy6 i.year


************************************************************************************
************************* TABLE 8 **************************************************

* T8 C1
* WDI data for employment starts in 1991
xtreg employment leader*autocracy6 i.year if year>1990

* T8 C2
xtreg g_tfp leader*autocracy6 i.year

* T8 C3
xtreg rec_simple_no leader*autocracy6 i.year

* T8 C4
xtreg rec_large_no leader*autocracy6 i.year

* T8 C5
xtreg expansion leader*autocracy6 i.year

************************************************************************************
************************* TABLE 9 **************************************************

* C1
xtreg rec_simple_no leader*autocracy6 lnbirth lndeath i.year
 
* C2
xtreg rec_simple_no leader*autocracy6  ucdp_type* i.year

* C3
xtreg rec_simple_no leader*autocracy6  wdi_gdpagr wdi_gdpind i.year

* C4
xtreg rec_simple_no leader*autocracy6  g_tfp i.year

* C5
xtreg rec_simple_no leader*autocracy6  wbgi_rle i.year

************************************************************************************
************************* TABLE 10 *************************************************

* C1
* First generate country-specific trends
egen cid2 = group(cid)
egen maxcid=max(cid2)
q tab cid2, gen(cfe)
local j=1
while (`j'< maxcid){
quietly gen cfe`j'trend = cfe`j'*year
label variable cfe`j'trend "Country-Specific Time Trend for cid`j'"
local j = `j' + 1
}
xtreg growth  leader*autocracy6   cfe*trend i.year

* C2
xtreg growth  leader*autocracy6   l.growth l2.growth l3.growth l4.growth i.year

* C3
xtreg growth  leader*autocracy6   g_f i.year

* C4
* Bazzi-Blattman data starts 1958
xtreg growth leader*autocracy6 i.year pshock_npi_p if year>1957

* C5
xtreg growth leader*autocracy6 i.year pshock_oilgas_npi if year>1957

* C6
xtreg growth leader*autocracy6 i.year rpgr_extract_npi_p rpgr_annual_npi_p rpgr_perennial_npi_p if year>1957

************************************************************************************
************************* TABLE 11 *************************************************

*C1
xtreg hf_prights leader*autocracy6  i.year if year>1994

*C2
xtreg growth leader*autocracy6  i.year durable

*C3
xtreg growth  leader*autocracy6  i.year colonial_dummy1  colonial_dummy2  colonial_dummy3  colonial_dummy4  colonial_dummy5  colonial_dummy6  colonial_dummy7  colonial_dummy8 

*C4
xtreg growth  leader*autocracy6   pct_autocratic

*C5
xtreg pubhealth_exp leader*autocracy6 i.year

*C6
xtreg education_exp leader*autocracy6 i.year


************************************************************************************
************************* TABLE A.13 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 5
forvalues j = 1(1)1268 {

g leader`j'autocracy5 = lfe`j' * autocracy5

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*autocracy5

* C2
xtreg growth leader*autocracy5 if tenurelength>2

* C3
xtreg growth leader*autocracy5 if tenurelength>5

* C4
xtreg growth leader*autocracy5 if tenurelength>10

* C5
xtreg growth leader*autocracy5 i.year

************************************************************************************
************************* TABLE A.14 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 4
forvalues j = 1(1)1268 {

g leader`j'autocracy4 = lfe`j' * autocracy4

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*autocracy4

* C2
xtreg growth leader*autocracy4 if tenurelength>2

* C3
xtreg growth leader*autocracy4 if tenurelength>5

* C4
xtreg growth leader*autocracy4 if tenurelength>10

* C5
xtreg growth leader*autocracy4 i.year

************************************************************************************
************************* TABLE A.15 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 3
forvalues j = 1(1)1268 {

g leader`j'autocracy3 = lfe`j' * autocracy3

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*autocracy3

* C2
xtreg growth leader*autocracy3 if tenurelength>2

* C3
xtreg growth leader*autocracy3 if tenurelength>5

* C4
xtreg growth leader*autocracy3 if tenurelength>10

* C5
xtreg growth leader*autocracy3 i.year

************************************************************************************
************************* TABLE A.16 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 2
forvalues j = 1(1)1268 {

g leader`j'autocracy2 = lfe`j' * autocracy2

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*autocracy2

* C2
xtreg growth leader*autocracy2 if tenurelength>2

* C3
xtreg growth leader*autocracy2 if tenurelength>5

* C4
xtreg growth leader*autocracy2 if tenurelength>10

* C5
xtreg growth leader*autocracy2 i.year


************************************************************************************
************************* TABLE A.17 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 1
forvalues j = 1(1)1268 {

g leader`j'autocracy1 = lfe`j' * autocracy1

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*_autocracy1

* C2
xtreg growth leader*autocracy1 if tenurelength>2

* C3
xtreg growth leader*autocracy1 if tenurelength>5

* C4
xtreg growth leader*autocracy1 if tenurelength>10

* C5
xtreg growth leader*autocracy1 i.year



************************************************************************************
************************* TABLE A.18 ***********************************************

* Make interactions between leader dummies and autocracy as defined by Polity2 < 0
forvalues j = 1(1)1268 {

g leader`j'autocracy0 = lfe`j' * autocracy0

}
* Repeat regressions from Table 4 in main text:

* C1
xtreg growth leader*autocracy0

* C2
xtreg growth leader*autocracy0 if tenurelength>2

* C3
xtreg growth leader*autocracy0 if tenurelength>5

* C4
xtreg growth leader*autocracy0 if tenurelength>10

* C5
xtreg growth leader*autocracy0 i.year

************************************************************************************
************************* TABLE A.19 ***********************************************

* see Table 5

************************************************************************************
************************* TABLE A.20 ***********************************************
* see Table 6

************************************************************************************
************************* TABLE A.21 ***********************************************
* see Table 9

************************************************************************************
************************* TABLE A.22 ***********************************************
* see Table 11

************************************************************************************
************************* TABLE A.23 ***********************************************
* see Table 10


************************************************************************************
************************************************************************************
****************** POST-ESTIMATION *************************************************
************************************************************************************
************************************************************************************

* Run this section after the regression of interest

* Step 1: save results
parmest, saving("results.dta", replace)

* Step 2: Save ancillary information from regression:
preserve
keep if e(sample)==1
* get p-value for F-test on joint significance of leader dummies
testparm leader*
g f_p = r(p)
* collect information on the number of years, number of countries in sample
egen minyear = min(year)
egen maxyear = max(year)
egen cid222 = group(cid)
cap drop r2a
cap drop n
* get R2
g r2 = e(r2_o)
* get N
g n = e(N)
cap drop test
g test = _n
keep if test==1
keep r2 n minyear maxyear  f_p
* store regression ancillary info
save "reg_info", replace
restore

* Step 3: Run tests
preserve
use "results.dta", clear
* keep leader*autocracy dummies
keep if regexm(parm, "leader")==1
drop if p==.
g NumParam = _N
* flag leader dummies that are positive and significant (p<0.025)
g pos_sig = 0
replace pos_sig = 1 if p<0.025 & estimate>0
* flag leader dummies that are negative and significant (p<0.025)
g neg_sig = 0
replace neg_sig = 1 if p<0.025 & estimate<0
ttest pos_sig=0.025
ttest neg_sig=0.025
sum estimate
restore

* Step 4: Display ancillary regression info
preserve
use "reg_info.dta", clear

list
restore
